About PROJECT
=============

PROJECT is supported and maintained by `Anaconda
<https://www.anaconda.com>`_.  PROJECT is part of the `HoloViz
<https://holoviz.org>`_ ecosystem, which strives to make browser-based
 data visualization in Python easier to use, easier to learn, and more
 powerful.

The primary PyViz developers are Philipp Rudiger, James A. Bednar,
Julia Signell and Jean-Luc Stevens, with bug reports and patches from
numerous members of the Github community.
